@@ -6,7 +6,11 @@ import pyttsx3 # pip install pyttsx3
 import speech_recognition as sr # pip install SpeechRecognition==3.8.0
 from googletrans import Translator # pip install googletrans
 import webbrowser
-fileopen = open("Api.txt","r")
+dx8 = "C:\python37\Lib\site-packages\pyliveofcode"
+dx9= dx8 + "\\Api.txt"
+dx10= dx8 + "\\chat_log.txt"
+dx11 = dx8 + "\\ qna.txt"
+fileopen = open(dx9,"r")
 API = fileopen.read()
 fileopen.close()
 
@@ -32,7 +36,7 @@ def math(n1umber,operators,n2umber):
     elif "//" in operators:
         print(int(n1umber)//int(n2umber))
 def chatbot(question,botname,chat_log = None):
-    FileLog = open("chat_log.txt","r")
+    FileLog = open(dx10,"r")
     chat_log_template = FileLog.read()
     FileLog.close()
     if chat_log is None:
@@ -49,7 +53,7 @@ def chatbot(question,botname,chat_log = None):
         presence_penalty = 0)
     answer = response.choices[0].text.strip()
     chat_log_template_update = chat_log_template + f"\nYou : {question} \n"+botname+":"+answer
-    FileLog = open("chat_log.txt","w")
+    FileLog = open(dx10,"w")
     FileLog.write(chat_log_template_update)
     FileLog.close()
     return answer
@@ -104,7 +108,7 @@ def inputtofile(dx,inputsreen):
     d.write(input1)
     d.close()
 # Api Key
-fileopen = open("Api.txt","r")
+fileopen = open(dx9,"r")
 API = fileopen.read()
 fileopen.close()
 
@@ -119,7 +123,7 @@ load_dotenv()
 completion = openai.Completion()
 
 def QuestionsAnswer(question,chat_log = None):
-    FileLog = open("qna_log.txt","r")
+    FileLog = open(dx11,"r")
     chat_log_template = FileLog.read()
     FileLog.close()
     if chat_log is None:
@@ -136,7 +140,7 @@ def QuestionsAnswer(question,chat_log = None):
         presence_penalty = 0)
     answer = response.choices[0].text.strip()
     chat_log_template_update = chat_log_template + f"\nQuestion : {question} \nAnswer : {answer}"
-    FileLog = open("qna_log.txt","w")
+    FileLog = open(dx11,"w")
     FileLog.write(chat_log_template_update)
     FileLog.close()
     return answer
